@@ -49,27 +49,22 @@
 
 package com.openexchange.subscribe.crawler;
 
-public class AbstractStep {
+import com.gargoylesoftware.htmlunit.WebClient;
+import com.openexchange.subscribe.SubscriptionException;
+
+public abstract class AbstractStep<O,I> implements Step<O,I>{
 
     protected String description;
 
     protected Exception exception;
 
     protected boolean executedSuccessfully;
-
-    static final String HTML_PAGE = "HtmlPage";
-
-    static final String LIST_OF_HTML_PAGES = "List of HtmlPages";
-
-    static final String TEXT_PAGE = "TextPage";
-
-    static final String LIST_OF_TEXT_PAGES = "List of TextPages";
-
-    static final String URL_STRING = "URL String";
-
-    static final String LIST_OF_CONTACT_OBJECTS = "List of ContactObjects";
-
-    static final String LIST_OF_HTML_ANCHORS = "List of HtmlAnchors";
+    
+    protected Workflow workflow;
+    
+    protected O output;
+    
+    protected I input;
 
     public boolean executedSuccessfully() {
         return executedSuccessfully;
@@ -78,5 +73,36 @@ public class AbstractStep {
     public Exception getException() {
         return this.exception;
     }
+    
+    public void setWorkflow (final Workflow workflow){
+        this.workflow = workflow;
+    }
 
+    public String getDescription() {
+        return description;
+    }
+    
+    public void setDescription(final String description) {
+        this.description = description;
+    }
+
+    public abstract void execute(WebClient webClient) throws SubscriptionException;
+
+    public Class inputType() {
+        return input.getClass();
+    }
+
+    public Class outputType() {
+        return output.getClass();
+    }
+
+    public O getOutput() {
+        return output;
+    }
+
+    public void setInput(final I input) {
+        this.input = input;
+        
+    }
+    
 }
