@@ -66,19 +66,17 @@ import com.openexchange.subscribe.SubscriptionException;
  * 
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
  */
-public class LoginPageByFormActionStep extends AbstractStep implements Step<HtmlPage, Object>, LoginStep {
+public class LoginPageByFormActionStep extends AbstractStep<HtmlPage, Object> implements LoginStep {
 
     private String url, username, password, actionOfLoginForm, nameOfUserField, nameOfPasswordField, linkAvailableAfterLogin, baseUrl;
 
     private int numberOfForm;
 
-    private HtmlPage currentPage;
-
     public LoginPageByFormActionStep() {
 
     }
 
-    public LoginPageByFormActionStep(String description, String url, String username, String password, String actionOfLoginForm, String nameOfUserField, String nameOfPasswordField, String linkAvailableAfterLogin, int numberOfForm, String baseUrl) {
+    public LoginPageByFormActionStep(final String description, final String url, final String username, final String password, final String actionOfLoginForm, final String nameOfUserField, final String nameOfPasswordField, final String linkAvailableAfterLogin, final int numberOfForm, final String baseUrl) {
         this.description = description;
         this.url = url;
         this.username = username;
@@ -91,29 +89,30 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
         this.baseUrl = baseUrl;
     }
 
-    public void execute(WebClient webClient) throws SubscriptionException {
+    @Override
+    public void execute(final WebClient webClient) throws SubscriptionException {
         HtmlPage loginPage;
         try {
             // Get the page, fill in the credentials and submit the login form identified by its action
-            loginPage = webClient.getPage(this.url);
+            loginPage = webClient.getPage(url);
             HtmlForm loginForm = null;
             int numberOfFormCounter = 1;
-            for (HtmlForm form : loginPage.getForms()) {
+            for (final HtmlForm form : loginPage.getForms()) {
                 if (form.getActionAttribute().startsWith(actionOfLoginForm) && numberOfForm == numberOfFormCounter & form.getInputsByName(nameOfUserField) != null) {
                     loginForm = form;
                 }
                 numberOfFormCounter++;
             }
             if (loginForm != null) {
-                HtmlTextInput userfield = loginForm.getInputByName(this.nameOfUserField);
-                userfield.setValueAttribute(this.username);
-                HtmlPasswordInput passwordfield = loginForm.getInputByName(this.nameOfPasswordField);
-                passwordfield.setValueAttribute(this.password);
+                final HtmlTextInput userfield = loginForm.getInputByName(nameOfUserField);
+                userfield.setValueAttribute(username);
+                final HtmlPasswordInput passwordfield = loginForm.getInputByName(nameOfPasswordField);
+                passwordfield.setValueAttribute(password);
                 final HtmlPage pageAfterLogin = (HtmlPage) loginForm.submit(null);
-                this.currentPage = pageAfterLogin;
+                output = pageAfterLogin;
 
                 boolean linkAvailable = false;
-                for (HtmlAnchor link : pageAfterLogin.getAnchors()) {
+                for (final HtmlAnchor link : pageAfterLogin.getAnchors()) {
                     if (link.getHrefAttribute().matches(linkAvailableAfterLogin)) {
                         linkAvailable = true;
                     }
@@ -123,32 +122,17 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
                 }
                 executedSuccessfully = true;
             }
-        } catch (FailingHttpStatusCodeException e) {
+        } catch (final FailingHttpStatusCodeException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
-        } catch (MalformedURLException e) {
+        } catch (final MalformedURLException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
-        } catch (IOException e) {
+        } catch (final IOException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
         }
     }
 
-    public HtmlPage getCurrentPage() {
-        return currentPage;
-    }
-
-    public String inputType() {
-        return null;
-    }
-
-    public String outputType() {
-        return HTML_PAGE;
-    }
-
-    public HtmlPage getOutput() {
-        return currentPage;
-    }
-
-    public void setInput(Object input) {
+    @Override
+    public void setInput(final Object input) {
         // this does nothing
     }
 
@@ -156,7 +140,7 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
         return url;
     }
 
-    public void setUrl(String url) {
+    public void setUrl(final String url) {
         this.url = url;
     }
 
@@ -164,7 +148,7 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
         return username;
     }
 
-    public void setUsername(String username) {
+    public void setUsername(final String username) {
         this.username = username;
     }
 
@@ -172,7 +156,7 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
         return password;
     }
 
-    public void setPassword(String password) {
+    public void setPassword(final String password) {
         this.password = password;
     }
 
@@ -180,15 +164,15 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
         return actionOfLoginForm;
     }
 
-    public void setActionOfLoginForm(String nameOfLoginForm) {
-        this.actionOfLoginForm = nameOfLoginForm;
+    public void setActionOfLoginForm(final String nameOfLoginForm) {
+        actionOfLoginForm = nameOfLoginForm;
     }
 
     public String getNameOfUserField() {
         return nameOfUserField;
     }
 
-    public void setNameOfUserField(String nameOfUserField) {
+    public void setNameOfUserField(final String nameOfUserField) {
         this.nameOfUserField = nameOfUserField;
     }
 
@@ -196,27 +180,23 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
         return nameOfPasswordField;
     }
 
-    public void setNameOfPasswordField(String nameOfPasswordField) {
+    public void setNameOfPasswordField(final String nameOfPasswordField) {
         this.nameOfPasswordField = nameOfPasswordField;
     }
 
-    public void setCurrentPage(HtmlPage currentPage) {
-        this.currentPage = currentPage;
-    }
-
     public String getPageTitleAfterLogin() {
         return linkAvailableAfterLogin;
     }
 
-    public void setPageTitleAfterLogin(String pageTitleAfterLogin) {
-        this.linkAvailableAfterLogin = pageTitleAfterLogin;
+    public void setPageTitleAfterLogin(final String pageTitleAfterLogin) {
+        linkAvailableAfterLogin = pageTitleAfterLogin;
     }
 
     public String getLinkAvailableAfterLogin() {
         return linkAvailableAfterLogin;
     }
 
-    public void setLinkAvailableAfterLogin(String linkAvailableAfterLogin) {
+    public void setLinkAvailableAfterLogin(final String linkAvailableAfterLogin) {
         this.linkAvailableAfterLogin = linkAvailableAfterLogin;
     }
 
@@ -224,7 +204,7 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
         return numberOfForm;
     }
 
-    public void setNumberOfForm(int numberOfForm) {
+    public void setNumberOfForm(final int numberOfForm) {
         this.numberOfForm = numberOfForm;
     }
 
@@ -232,7 +212,7 @@ public class LoginPageByFormActionStep extends AbstractStep implements Step<Html
         return baseUrl;
     }
 
-    public void setBaseUrl(String baseUrl) {
+    public void setBaseUrl(final String baseUrl) {
         this.baseUrl = baseUrl;
     }
 
