@@ -66,17 +66,14 @@ import com.openexchange.subscribe.SubscriptionException;
  * 
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
  */
-public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object>, LoginStep {
+public class LoginPageStep extends AbstractStep<HtmlPage, Object> implements LoginStep {
 
     private String url, username, password, nameOfLoginForm, nameOfUserField, nameOfPasswordField, linkAvailableAfterLogin, baseUrl;
 
-    private HtmlPage currentPage;
-
     public LoginPageStep() {
-
     }
 
-    public LoginPageStep(String description, String url, String username, String password, String nameOfLoginForm, String nameOfUserField, String nameOfPasswordField, String linkAvailableAfterLogin, String baseUrl) {
+    public LoginPageStep(final String description, final String url, final String username, final String password, final String nameOfLoginForm, final String nameOfUserField, final String nameOfPasswordField, final String linkAvailableAfterLogin, final String baseUrl) {
         this.description = description;
         this.url = url;
         this.username = username;
@@ -88,22 +85,23 @@ public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object
         this.baseUrl = baseUrl;
     }
 
-    public void execute(WebClient webClient) throws SubscriptionException {
+    @Override
+    public void execute(final WebClient webClient) throws SubscriptionException {
         HtmlPage loginPage;
         try {
             // Get the page, fill in the credentials and submit the login form
-            loginPage = webClient.getPage(this.url);
-            HtmlForm loginForm = loginPage.getFormByName(this.nameOfLoginForm);
-            HtmlTextInput userfield = loginForm.getInputByName(this.nameOfUserField);
-            userfield.setValueAttribute(this.username);
-            HtmlPasswordInput passwordfield = loginForm.getInputByName(this.nameOfPasswordField);
-            passwordfield.setValueAttribute(this.password);
+            loginPage = webClient.getPage(url);
+            final HtmlForm loginForm = loginPage.getFormByName(nameOfLoginForm);
+            final HtmlTextInput userfield = loginForm.getInputByName(nameOfUserField);
+            userfield.setValueAttribute(username);
+            final HtmlPasswordInput passwordfield = loginForm.getInputByName(nameOfPasswordField);
+            passwordfield.setValueAttribute(password);
             final HtmlPage pageAfterLogin = (HtmlPage) loginForm.submit(null);
-            this.currentPage = pageAfterLogin;
+            output = pageAfterLogin;
 
             // if this link is not on the page the login did not work
             boolean linkAvailable = false;
-            for (HtmlAnchor link : pageAfterLogin.getAnchors()) {
+            for (final HtmlAnchor link : pageAfterLogin.getAnchors()) {
                 if (link.getHrefAttribute().contains(linkAvailableAfterLogin)) {
                     linkAvailable = true;
                 }
@@ -112,40 +110,20 @@ public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object
                 throw SubscriptionErrorMessage.INVALID_LOGIN.create();
             }
             executedSuccessfully = true;
-        } catch (FailingHttpStatusCodeException e) {
+        } catch (final FailingHttpStatusCodeException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
-        } catch (MalformedURLException e) {
+        } catch (final MalformedURLException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
-        } catch (IOException e) {
+        } catch (final IOException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
         }
     }
 
-    public HtmlPage getCurrentPage() {
-        return currentPage;
-    }
-
-    public String inputType() {
-        return null;
-    }
-
-    public String outputType() {
-        return HTML_PAGE;
-    }
-
-    public HtmlPage getOutput() {
-        return currentPage;
-    }
-
-    public void setInput(Object input) {
-        // this does nothing
-    }
-
     public String getUrl() {
         return url;
     }
 
-    public void setUrl(String url) {
+    public void setUrl(final String url) {
         this.url = url;
     }
 
@@ -153,7 +131,7 @@ public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object
         return username;
     }
 
-    public void setUsername(String username) {
+    public void setUsername(final String username) {
         this.username = username;
     }
 
@@ -161,7 +139,7 @@ public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object
         return password;
     }
 
-    public void setPassword(String password) {
+    public void setPassword(final String password) {
         this.password = password;
     }
 
@@ -169,7 +147,7 @@ public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object
         return nameOfLoginForm;
     }
 
-    public void setNameOfLoginForm(String nameOfLoginForm) {
+    public void setNameOfLoginForm(final String nameOfLoginForm) {
         this.nameOfLoginForm = nameOfLoginForm;
     }
 
@@ -177,7 +155,7 @@ public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object
         return nameOfUserField;
     }
 
-    public void setNameOfUserField(String nameOfUserField) {
+    public void setNameOfUserField(final String nameOfUserField) {
         this.nameOfUserField = nameOfUserField;
     }
 
@@ -185,27 +163,23 @@ public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object
         return nameOfPasswordField;
     }
 
-    public void setNameOfPasswordField(String nameOfPasswordField) {
+    public void setNameOfPasswordField(final String nameOfPasswordField) {
         this.nameOfPasswordField = nameOfPasswordField;
     }
 
-    public void setCurrentPage(HtmlPage currentPage) {
-        this.currentPage = currentPage;
-    }
-
     public String getPageTitleAfterLogin() {
         return linkAvailableAfterLogin;
     }
 
-    public void setPageTitleAfterLogin(String pageTitleAfterLogin) {
-        this.linkAvailableAfterLogin = pageTitleAfterLogin;
+    public void setPageTitleAfterLogin(final String pageTitleAfterLogin) {
+        linkAvailableAfterLogin = pageTitleAfterLogin;
     }
 
     public String getLinkAvailableAfterLogin() {
         return linkAvailableAfterLogin;
     }
 
-    public void setLinkAvailableAfterLogin(String linkAvailableAfterLogin) {
+    public void setLinkAvailableAfterLogin(final String linkAvailableAfterLogin) {
         this.linkAvailableAfterLogin = linkAvailableAfterLogin;
     }
 
@@ -213,7 +187,7 @@ public class LoginPageStep extends AbstractStep implements Step<HtmlPage, Object
         return baseUrl;
     }
 
-    public void setBaseUrl(String baseUrl) {
+    public void setBaseUrl(final String baseUrl) {
         this.baseUrl = baseUrl;
     }
 
