@@ -62,12 +62,10 @@ import com.openexchange.subscribe.SubscriptionException;
  * 
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
  */
-public class PageByUrlStep extends AbstractStep implements Step<HtmlPage, Object> {
+public class PageByUrlStep extends AbstractStep<HtmlPage, Object> {
 
     private String url;
 
-    private HtmlPage currentPage;
-
     private Exception exception;
 
     private boolean executedSuccessfully;
@@ -76,46 +74,38 @@ public class PageByUrlStep extends AbstractStep implements Step<HtmlPage, Object
 
     }
 
-    public PageByUrlStep(String description, String url) {
+    public PageByUrlStep(final String description, final String url) {
         this.description = description;
         this.url = url;
     }
 
-    public void execute(WebClient webClient) throws SubscriptionException {
+    @Override
+    public void execute(final WebClient webClient) throws SubscriptionException {
         try {
-            HtmlPage pageByUrl = webClient.getPage(this.url);
-            this.currentPage = pageByUrl;
+            final HtmlPage pageByUrl = webClient.getPage(url);
+            output = pageByUrl;
             executedSuccessfully = true;
-        } catch (FailingHttpStatusCodeException e) {
+        } catch (final FailingHttpStatusCodeException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
-        } catch (MalformedURLException e) {
+        } catch (final MalformedURLException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
-        } catch (IOException e) {
+        } catch (final IOException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
         }
     }
 
+    @Override
     public boolean executedSuccessfully() {
-        return this.executedSuccessfully;
+        return executedSuccessfully;
     }
 
+    @Override
     public Exception getException() {
-        return this.exception;
+        return exception;
     }
 
-    public String inputType() {
-        return HTML_PAGE;
-    }
-
-    public String outputType() {
-        return HTML_PAGE;
-    }
-
-    public HtmlPage getOutput() {
-        return currentPage;
-    }
-
-    public void setInput(Object input) {
+    @Override
+    public void setInput(final Object input) {
         // this needs to do nothing
     }
 
@@ -123,27 +113,19 @@ public class PageByUrlStep extends AbstractStep implements Step<HtmlPage, Object
         return url;
     }
 
-    public void setUrl(String url) {
+    public void setUrl(final String url) {
         this.url = url;
     }
 
-    public HtmlPage getCurrentPage() {
-        return currentPage;
-    }
-
-    public void setCurrentPage(HtmlPage currentPage) {
-        this.currentPage = currentPage;
-    }
-
     public boolean isExecutedSuccessfully() {
         return executedSuccessfully;
     }
 
-    public void setExecutedSuccessfully(boolean executedSuccessfully) {
+    public void setExecutedSuccessfully(final boolean executedSuccessfully) {
         this.executedSuccessfully = executedSuccessfully;
     }
 
-    public void setException(Exception exception) {
+    public void setException(final Exception exception) {
         this.exception = exception;
     }
 
