@@ -65,29 +65,27 @@ import com.openexchange.subscribe.SubscriptionException;
  * 
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
  */
-public class TextPagesByLinkStep extends AbstractStep implements Step<List<TextPage>, HtmlPage> {
-
-    private HtmlPage htmlPage;
+public class TextPagesByLinkStep extends AbstractStep<List<TextPage>, HtmlPage>{
 
     private String urlBeforeOffset, urlAfterOffset, linkpart;
 
     private int offset;
 
-    private List<TextPage> returnedPages = new ArrayList<TextPage>();
-
     public TextPagesByLinkStep() {
-
+        output = new ArrayList<TextPage>();
     }
 
-    public TextPagesByLinkStep(String description, String urlBeforeOffset, int offset, String urlAfterOffset, String linkpart) {
+    public TextPagesByLinkStep(final String description, final String urlBeforeOffset, final int offset, final String urlAfterOffset, final String linkpart) {
         this.description = description;
         this.urlBeforeOffset = urlBeforeOffset;
         this.urlAfterOffset = urlAfterOffset;
         this.offset = offset;
         this.linkpart = linkpart;
+        output = new ArrayList<TextPage>();
     }
 
-    public void execute(WebClient webClient) throws SubscriptionException {
+    @Override
+    public void execute(final WebClient webClient) throws SubscriptionException {
         try {
 
             int tempOffset = 0;
@@ -95,69 +93,39 @@ public class TextPagesByLinkStep extends AbstractStep implements Step<List<TextP
 
             while (oneSuccess) {
                 oneSuccess = false;
-                HtmlPage tempPage = webClient.getPage(urlBeforeOffset + Integer.toString(tempOffset) + urlAfterOffset);
-                List<HtmlAnchor> allLinks = tempPage.getAnchors();
-                for (HtmlAnchor link : allLinks) {
+                final HtmlPage tempPage = webClient.getPage(urlBeforeOffset + Integer.toString(tempOffset) + urlAfterOffset);
+                final List<HtmlAnchor> allLinks = tempPage.getAnchors();
+                for (final HtmlAnchor link : allLinks) {
                     if (link.getHrefAttribute().startsWith(linkpart)) {
                         oneSuccess = true;
-                        TextPage tempTextPage = link.click();
-                        returnedPages.add(tempTextPage);
+                        final TextPage tempTextPage = link.click();
+                        output.add(tempTextPage);
                     }
                 }
                 tempOffset += offset;
             }
             executedSuccessfully = true;
 
-        } catch (FailingHttpStatusCodeException e) {
-            this.exception = e;
-        } catch (MalformedURLException e) {
-            this.exception = e;
-        } catch (IOException e) {
-            this.exception = e;
+        } catch (final FailingHttpStatusCodeException e) {
+            exception = e;
+        } catch (final MalformedURLException e) {
+            exception = e;
+        } catch (final IOException e) {
+            exception = e;
         }
 
     }
 
+    @Override
     public boolean executedSuccessfully() {
         return executedSuccessfully;
     }
 
+    @Override
     public Exception getException() {
         return exception;
     }
 
-    public String inputType() {
-        return HTML_PAGE;
-    }
-
-    public String outputType() {
-        return LIST_OF_TEXT_PAGES;
-    }
-
-    public List<TextPage> getOutput() {
-        return returnedPages;
-    }
-
-    public void setInput(HtmlPage input) {
-        this.htmlPage = input;
-    }
-
-    public HtmlPage getHtmlPage() {
-        return htmlPage;
-    }
-
-    public void setHtmlPage(HtmlPage htmlPage) {
-        this.htmlPage = htmlPage;
-    }
-
-    public List<TextPage> getReturnedPages() {
-        return returnedPages;
-    }
-
-    public void setReturnedPages(List<TextPage> returnedPages) {
-        this.returnedPages = returnedPages;
-    }
-
     public String getUrlBeforeOffset() {
         return urlBeforeOffset;
     }
@@ -174,19 +142,19 @@ public class TextPagesByLinkStep extends AbstractStep implements Step<List<TextP
         return offset;
     }
 
-    public void setUrlBeforeOffset(String urlBeforeOffset) {
+    public void setUrlBeforeOffset(final String urlBeforeOffset) {
         this.urlBeforeOffset = urlBeforeOffset;
     }
 
-    public void setUrlAfterOffset(String urlAfterOffset) {
+    public void setUrlAfterOffset(final String urlAfterOffset) {
         this.urlAfterOffset = urlAfterOffset;
     }
 
-    public void setLinkpart(String linkpart) {
+    public void setLinkpart(final String linkpart) {
         this.linkpart = linkpart;
     }
 
-    public void setOffset(int offset) {
+    public void setOffset(final int offset) {
         this.offset = offset;
     }
 
