@@ -52,8 +52,10 @@ package com.openexchange.subscribe.crawler;
 import java.util.List;
 import org.ho.yaml.Yaml;
 import com.gargoylesoftware.htmlunit.BrowserVersion;
+import com.gargoylesoftware.htmlunit.ThreadedRefreshHandler;
 import com.gargoylesoftware.htmlunit.WebClient;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.subscribe.SubscriptionException;
 import com.openexchange.subscribe.crawler.darkside.WebClientCloser;
@@ -71,17 +73,22 @@ public class Workflow {
 
     private String loginStepString;
 
+    private Subscription subscription;
+
+    private boolean useThreadedRefreshHandler;
+
     public Workflow() {
 
     }
 
-    public Workflow(List<Step> steps) {
+    public Workflow(final List<Step> steps) {
         this.steps = steps;
+        useThreadedRefreshHandler = false;
     }
 
     // Convenience method for setting username and password after the workflow was created
-    public Contact[] execute(String username, String password) throws SubscriptionException {
-        for (Step currentStep : steps) {
+    public Contact[] execute(final String username, final String password) throws SubscriptionException {
+        for (final Step currentStep : steps) {
             if (currentStep instanceof LoginStep) {
                 ((LoginStep) currentStep).setUsername(username);
                 ((LoginStep) currentStep).setPassword(password);
@@ -100,23 +107,31 @@ public class Workflow {
         final WebClient webClient = new WebClient(BrowserVersion.FIREFOX_2);
         // Javascript needs to be disabled for security reasons
         webClient.setJavaScriptEnabled(false);
+        if (useThreadedRefreshHandler) {
+            webClient.setRefreshHandler(new ThreadedRefreshHandler());
+        }
         try {
 
             Step previousStep = null;
+            Object result = null;
 
-            for (Step currentStep : steps) {
+            for (final Step currentStep : steps) {
                 if (previousStep != null) {
                     currentStep.setInput(previousStep.getOutput());
                 }
+                currentStep.setWorkflow(this);
                 currentStep.execute(webClient);
                 previousStep = currentStep;
                 if (!currentStep.executedSuccessfully()) {
                     throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create();
                 }
+                if (!(currentStep instanceof LogoutStep)) {
+                    result = currentStep.getOutput();
+                }
             }
 
             webClient.closeAllWindows();
-            return (Contact[]) previousStep.getOutput();
+            return (Contact[]) result;
         } finally {
             closer.close(webClient);
         }
@@ -126,8 +141,32 @@ public class Workflow {
         return steps;
     }
 
-    public void setSteps(List<Step> steps) {
+    public void setSteps(final List<Step> steps) {
         this.steps = steps;
     }
 
+    public Subscription getSubscription() {
+        return subscription;
+    }
+
+    public void setSubscription(final Subscription subscription) {
+        this.subscription = subscription;
+    }
+
+    public String getLoginStepString() {
+        return loginStepString;
+    }
+
+    public void setLoginStepString(final String loginStepString) {
+        this.loginStepString = loginStepString;
+    }
+
+    public boolean isUseThreadedRefreshHandler() {
+        return useThreadedRefreshHandler;
+    }
+
+    public void setUseThreadedRefreshHandler(final boolean useThreadedRefreshHandler) {
+        this.useThreadedRefreshHandler = useThreadedRefreshHandler;
+    }
+
 }
